molpy
==============================
[//]: # (Badges)

[![Travis Build Status](https://travis-ci.com/yonghui-cc/molpy.svg?branch=master)](https://travis-ci.com/yonghui-cc/molpy)
[![AppVeyor Build status](https://ci.appveyor.com/api/projects/status/github/yonghui-cc/molpy/branch/master?svg=true)](https://ci.appveyor.com/project/yonghui-cc/molpy/branch/master)
[![codecov](https://codecov.io/gh/yonghui-cc/molpy/branch/master/graph/badge.svg)](https://codecov.io/gh/yonghui-cc/molpy/branch/master)
![](https://img.shields.io/badge/language-python-orange.svg)
![](https://img.shields.io/badge/platform-ios-lightgrey.svg)


A learning example for best practice

This is version 1.0

This is version 1.1

Change from github

### Copyright

Copyright (c) 2020, Yonghui Chen


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.1.
